@@ -9,6 +9,7 @@ from sys import exit as s_exit, stderr
 import logging
 import urllib.parse as ul
 import json
+import re
 from regapp_tools.parse_args import args
 from regapp_tools.config import CONFIG
 from regapp_tools.bwidmconnection import BwIdmConnection
@@ -27,6 +28,8 @@ def external_id_from_subiss(sub=None, iss=None, sub_iss=None):
     if isinstance(sub_iss, list):
         sub_iss = sub_iss[0]
 
+    logger.debug(F"sub iss: {sub_iss}")
+
     # Values for testing:
     if sub_iss == 'test-offline':
         stderr.write("Offline test: %s\n" % sub_iss)
@@ -211,3 +214,13 @@ def get_list_of_registrations_in_service(service):
     resp = BWIDM.get ('external-reg', 'find', 'all', 'ssn', service)
     resp_json = safe_resp_conversion(resp)
     return resp_json
+def unmask_from_bwidm(external_id):
+    if not re.search("http", external_id):
+        sub, iss = external_id.split('@')
+        iss = iss.replace('-','/')
+        iss = ul.quote_plus("https://"+iss)
+        external_id = F"{sub}@{iss}"
+        # print (F"external_ID: {external_id}")
+        # import sys
+        # sys.exit(0)
+        return external_id
