@@ -26,7 +26,7 @@ def parseOptions():
     parser.add_argument('--verbose', '-v'        , default=0   , action="count", help="Verbosity")
     parser.add_argument('--debug',   '-d'        , default=False   , action="store_true" )
     parser.add_argument('--config', '-c'         , default=None)
-    parser.add_argument(dest='sub_iss'           , default=None, nargs='*', help='Content of $REMOTE_USER. For testing use "test-offline" and "test-id"')
+    parser.add_argument(dest='sub_iss'           , default=None, nargs='?', help='Content of $REMOTE_USER. For testing use "test-offline" and "test-id"')
     parser.add_argument('--ssh', '-s'            , default=False, action="store_true")
     parser.add_argument('--reg', '-r'            , default=False, action="store_true")
     parser.add_argument('--grp', '-g'            , default=False, action="store_true")
@@ -44,8 +44,6 @@ def parseOptions():
     args.base_url   = args.base_url.rstrip('/')
     args.bwidmOrgId = remove_quotes(args.bwidmOrgId)
 
-    args.username = args.sub_iss
-
     if args.all:
         args.grp=True
         args.info=True
@@ -62,6 +60,22 @@ def parseOptions():
             pass
     else:
         args.info = True
+        
+    #FIXME: This brings confusion:
+    args.username = args.sub_iss
+
+    # Values for testing: (logger.error is used, because logging is not set up yet
+    print ("")
+    if args.sub_iss == "test-id":
+        args.sub_iss = "6c611e2a-2c1c-487f-9948-c058a36c8f0e@https://login.helmholtz-data-federation.de/oauth2"
+        logger.error(F"using test-id: {args.sub_iss}")
+    if args.sub_iss == 'test-marcus':
+        args.sub_iss = "6c611e2a-2c1c-487f-9948-c058a36c8f0e@https://login.helmholtz-data-federation.de/oauth2"
+        logger.error("using test id: %s" % args.sub_iss)
+    if args.sub_iss == 'test-borja':
+        args.sub_iss = "309ed509-c56a-4894-b163-5993bd08cbc2@https://login.helmholtz-data-federation.de/oauth2"
+        logger.error("using test id: %s" % args.sub_iss)
+
 
     return args
 
